import React from 'react'
import { UseFormReturn } from 'react-hook-form'

interface SelectProps extends Partial<Pick<UseFormReturn, 'register'>> {
  options: Array<string>
  name: string
  type?: 'text' | 'email' | 'number'
}

function Select(props: SelectProps) {
  const { register, options, name, ...rest } = props
  if (register === undefined) {
    return <></>
  }
  return (
    // eslint-disable-next-line react/jsx-props-no-spreading
    <select {...register(name)} {...rest}>
      {options.map((value) => (
        <option key={value} value={value}>
          {value}
        </option>
      ))}
    </select>
  )
}

Select.defaultProps = {
  type: 'text',
}

export default Select
