import React from 'react'
import { render, waitFor, screen } from 'test-utils'
import i18n from 'i18next'
import { initReactI18next } from 'react-i18next'
import userEvent from '@testing-library/user-event'
import AdapterDateFns from '@mui/lab/AdapterDateFns'
import { LocalizationProvider } from '@mui/lab'
import Register from './index'

// TODO: can this be initialized in 'test-utils'? should we stub it?
//       see https://react.i18next.com/misc/testing
i18n.use(initReactI18next).init({
  lng: 'en',
  fallbackLng: 'en',

  // Have a common namespace used around the full app
  ns: ['translations'],
  defaultNS: 'translations',

  debug: false,

  resources: { en: { translations: {} } },
})

test('Validation message showing if last name is missing', async () => {
  render(
    <LocalizationProvider dateAdapter={AdapterDateFns}>
      <Register />
    </LocalizationProvider>)

  const firstNameLabel = i18n.t('input.firstName').toString()
  const firstNameComponent = screen.getByLabelText(firstNameLabel)
  expect(firstNameComponent).toBeInTheDocument()

  userEvent.type(firstNameComponent, 'Test')

  // Try to go to the next step and check that the validation message is showing
  const submitButton = screen.getByTestId('button-next')
  userEvent.click(submitButton)

  const validationLastName = i18n
    .t('common:validation.lastNameRequired')
    .toString()
  await waitFor(() => screen.getByText(validationLastName))

  const validationMessage = screen.getByText(validationLastName)
  expect(validationMessage).toBeInTheDocument()
})
