from datetime import datetime

from django.db.models import Q, When, Case, BooleanField
from django_filters.rest_framework import (
    BaseInFilter,
    BooleanFilter,
    FilterSet,
)

from greg.models import (
    Person,
    Role,
    Identity,
)


class RoleFilter(FilterSet):
    type = BaseInFilter(field_name="role__type", lookup_expr="in")

    class Meta:
        model = Role
        fields = ["type"]


class PersonFilter(FilterSet):
    verified = BooleanFilter(
        field_name="identities__verified_by_id", lookup_expr="isnull", exclude=True
    )
    active = BooleanFilter(method="active_role_filter")

    class Meta:
        model = Person
        fields = ["first_name", "last_name", "verified", "active"]

    def active_role_filter(self, queryset, name, value):
        if value:
            datetime_now = datetime.now()
            return queryset.annotate(
                active=Case(
                    When(
                        Q(roles__start_date__isnull=True)
                        | Q(roles__start_date__lte=datetime_now),
                        roles__end_date__gte=datetime_now,
                        then=True,
                    ),
                    default=False,
                    output_field=BooleanField(),
                )
            ).filter(active=value)

        return queryset


class IdentityFilter(FilterSet):
    class Meta:
        model = Identity
        fields = ["type", "verified_by_id"]
