import datetime

from django.db import transaction
from django.utils import timezone
from rest_framework import serializers

from greg.models import Invitation, InvitationLink, Person, Role
from gregui.api.serializers.role import RoleSerializerUi
from gregui.models import GregUserProfile


class InviteGuestSerializer(serializers.ModelSerializer):
    role = RoleSerializerUi()
    uuid = serializers.UUIDField(read_only=True)

    def create(self, validated_data):
        role_data = validated_data.pop("role")

        user = GregUserProfile.objects.get(user=self.context["request"].user)

        # Create objects
        with transaction.atomic():
            person = Person.objects.create(**validated_data)
            role_data["person"] = person
            role_data["sponsor_id"] = user.sponsor
            role = Role.objects.create(**role_data)
            invitation = Invitation.objects.create(role=role)
            InvitationLink.objects.create(
                invitation=invitation,
                expire=timezone.now() + datetime.timedelta(days=30),
            )
        return person

    class Meta:
        model = Person
        fields = ("id", "first_name", "last_name", "date_of_birth", "role", "uuid")
        read_only_field = ("uuid",)


foo = InviteGuestSerializer()
