import pytest
from rest_framework import status
from rest_framework.reverse import reverse
from rest_framework.test import APIRequestFactory, force_authenticate

from greg.models import Person
from gregui.api.views.invitation import CreateInvitationView


@pytest.mark.django_db
def test_invite_guest(client, user_sponsor, unit_foo, role_type_foo):
    data = {'first_name': 'Foo', 'last_name': 'Bar', 'email': 'test@example.com', 'role': {
        'start_date': '2019-08-06',
        'end_date': '2019-08-10',
        'orgunit_id': unit_foo.id,
        'type': role_type_foo.id
    }}
    url = reverse('gregui-v1:invite-create')

    all_persons = Person.objects.all()
    assert len(all_persons) == 0

    factory = APIRequestFactory()
    request = factory.post(url, data, format='json')
    force_authenticate(request, user=user_sponsor)

    view = CreateInvitationView.as_view()
    response = view(request)

    assert response.status_code == status.HTTP_201_CREATED

    all_persons = Person.objects.all()

    assert len(all_persons) == 1
    assert all_persons[0].first_name == 'Foo'
    assert all_persons[0].last_name == 'Bar'
