from django.core import mail

import pytest
from gregui import mailutils


@pytest.mark.django_db
def test_registration_template():
    prefilled_template = """Dette er en automatisk generert melding fra gjesteregistreringstjenesten.
Du har blitt registrert som gjest på InstanceName av Foo Bar.
For å fullføre registreringen av gjestekontoen følg denne lenken: www.google.com

This message has been automatically generated by the guest registration system.
You have been registered as a guest at InstanceName by Foo Bar.
To complete the registration of your guest account, please follow this link: www.google.com
"""
    rendered_template = mailutils.registration_template("InstanceName", "Foo Bar")
    assert rendered_template == prefilled_template


@pytest.mark.django_db
def test_confirmation_template():
    prefilled_template = """Dette er en automatisk generert melding fra gjesteregistreringstjenesten.
Din gjest, Foo Bar, har fullført registrering, bekreft gjesten her: www.google.com

This message has been automatically generated by the guest registration system.
Your guest, Foo Bar, has completed their registration, please confirm the guest here: www.google.com
"""
    rendered_template = mailutils.confirmation_template("Foo Bar")
    assert rendered_template == prefilled_template


@pytest.mark.django_db
def test_registration_mail():
    mail.outbox = []
    assert mailutils.send_registration_mail("test@example.no", "Foo") == 1
    assert len(mail.outbox) == 1
    assert mail.outbox[0].to == ["test@example.no"]


@pytest.mark.django_db
def test_confirmation_mail():
    mail.outbox = []
    assert mailutils.send_confirmation_mail("test@example.no", "Foo") == 1
    assert len(mail.outbox) == 1
    assert mail.outbox[0].to == ["test@example.no"]
